@@ -383,7 +383,7 @@ static int do_sqlite_bind(sqlite3 *db, sqlite3_stmt *ppStmt, int num, int i)
 {
    char *svalue;
    SLang_BString_Type *bvalue;
-   unsigned int bstrlen;
+   SLstrlen_Type bstrlen;
    unsigned char *bptr;
 
 #define MAP(slangtype, ctype, slangpop, sqlitebind) \
